@@ -27,7 +27,6 @@ test_generator = None
 
 
 def pytest_configure(config):
-    global test_generator
     """
     Setup configuration after command-line options are parsed
     """
@@ -41,6 +40,14 @@ def pytest_configure(config):
         "markers",
         "splunk_searchtime_fields_positive: Test search time fields positive scenarios only",
     )
+    config.addinivalue_line(
+        "markers",
+        "splunk_requirements: Tests that cover old requirement tests",
+    )
+    config.addinivalue_line(
+        "markers",
+        "splunk_searchtime_fields_requirements: Test checking fields from cim_fields",
+    )
     config.addinivalue_line(
         "markers",
         "splunk_searchtime_fields_negative: Test search time fields negative scenarios only",
@@ -48,6 +55,10 @@ def pytest_configure(config):
     config.addinivalue_line(
         "markers", "splunk_searchtime_fields_tags: Test search time tags only"
     )
+    config.addinivalue_line(
+        "markers",
+        "splunk_searchtime_fields_datamodels: Test checking datamodel defined in model",
+    )
     config.addinivalue_line(
         "markers",
         "splunk_searchtime_fields_eventtypes: Test search time eventtypes only",
@@ -78,8 +89,10 @@ def pytest_configure(config):
         "markers",
         "splunk_searchtime_requirements: Test an requirement test only  is mapped with only one data models",
     )
-    if config.getoption("splunk_app", None):
-        test_generator = AppTestGenerator(config)
+    config.addinivalue_line(
+        "markers",
+        "splunk_requirements_unit: Test checking if all fields for datamodel are defined in cim_fields and missing_recommended_fields",
+    )
 
     cim_report = config.getoption("cim_report")
     if cim_report and not hasattr(config, "slaveinput"):
@@ -96,7 +109,7 @@ def pytest_unconfigure(config):
 
 
 def pytest_sessionstart(session):
-
+    global test_generator
     SampleXdistGenerator.event_path = session.config.getoption("event_path")
     SampleXdistGenerator.event_stored = False
     SampleXdistGenerator.tokenized_event_source = session.config.getoption(
@@ -114,6 +127,8 @@ def pytest_sessionstart(session):
         store_events = session.config.getoption("store_events")
         sample_generator = SampleXdistGenerator(app_path, config_path)
         sample_generator.get_samples(store_events)
+    if session.config.getoption("splunk_app", None):
+        test_generator = AppTestGenerator(session.config)
 
 
 def pytest_generate_tests(metafunc):
