@@ -1,10 +1,27 @@
+#
+# Copyright 2021 Splunk Inc.
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+# http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+#
 # -*- coding: utf-8 -*-
 """
 Provides the helper methods to test addon_parser.Field object
 """
 import logging
 import json
-from .field_test_adapter import FieldTestAdapater
+from .field_test_adapter import FieldTestAdapter
+from ..utilities.log_helper import get_table_output
+from ..utilities.log_helper import format_search_query_log
 
 
 class FieldTestHelper(object):
@@ -22,7 +39,7 @@ class FieldTestHelper(object):
 
     def __init__(self, search_util, fields, interval=10, retries=4):
         self.search_util = search_util
-        self.fields = FieldTestAdapater.get_test_fields(fields)
+        self.fields = FieldTestAdapter.get_test_fields(fields)
         self.interval = interval
         self.retries = retries
 
@@ -110,18 +127,18 @@ class FieldTestHelper(object):
                     "field": each_field,
                     "field_count": int(
                         each_result.get(
-                            FieldTestAdapater.FIELD_COUNT.format(each_field.name)
+                            FieldTestAdapter.FIELD_COUNT.format(each_field.name)
                         )
                     ),
                 }
                 if each_field.gen_validity_query():
                     field_dict["valid_field_count"] = int(
                         each_result.get(
-                            FieldTestAdapater.VALID_FIELD_COUNT.format(each_field.name)
+                            FieldTestAdapter.VALID_FIELD_COUNT.format(each_field.name)
                         )
                     )
                     field_dict["invalid_values"] = each_result.get(
-                        FieldTestAdapater.INVALID_FIELD_VALUES.format(each_field.name),
+                        FieldTestAdapter.INVALID_FIELD_VALUES.format(each_field.name),
                         "-",
                     )
                 field_dict.update(
@@ -175,7 +192,7 @@ class FieldTestHelper(object):
 
         """
         if not self.fields:
-            exc_message = self.get_table_output(
+            exc_message = get_table_output(
                 headers=["Source", "Sourcetype", "Event Count"],
                 value_list=[
                     [
@@ -187,7 +204,7 @@ class FieldTestHelper(object):
                 ],
             )
         elif len(self.fields) >= 1:
-            exc_message = self.get_table_output(
+            exc_message = get_table_output(
                 headers=[
                     "Source",
                     "Sourcetype",
@@ -217,36 +234,9 @@ class FieldTestHelper(object):
                     for each_result in self.parsed_result
                 ],
             )
-        exc_message += f"\n\nSearch = {self.search}"
+        exc_message += f"{format_search_query_log(self.search)}"
         for each_field in self.fields:
             exc_message += (
                 f"\n\nProperties for the field :: {each_field.get_properties()}"
             )
         return exc_message
-
-    @staticmethod
-    def get_table_output(headers, value_list):
-        """
-        Generate a table output of the following format::
-
-            Header1 | Header2
-            ---------------
-            One     | Value1
-            Two     | Value2
-            --------------
-
-        Args:
-            headers (list): list of headers
-            value_list (list of list): list of rows for the table
-        """
-        table_output = ""
-        table_list = [headers] + value_list
-        col_length = [
-            max(map(lambda cell: len(str(cell)), col)) for col in zip(*table_list)
-        ]
-        format_str = " | ".join(["{{:<{}}}".format(i) for i in col_length])
-        # Separating line
-        table_list.insert(1, ["-" * i for i in col_length])
-        for each_value in table_list:
-            table_output += format_str.format(*each_value) + "\n"
-        return table_output
