@@ -22,6 +22,8 @@ import copy
 
 from math import ceil
 from ..cim_tests import FieldTestHelper
+from ..utilities.log_helper import format_search_query_log
+from ..utilities.log_helper import get_table_output
 
 MAX_TIME_DIFFERENCE = 45
 LOGGER = logging.getLogger("pytest-splunk-addon")
@@ -108,7 +110,9 @@ class IndexTimeTestTemplate(object):
         LOGGER.debug("Results:{}".format(results))
 
         if not results:
-            assert False, "No Events found for query " + search
+            assert False, (
+                f"\nNo Events found for query." f"{format_search_query_log(search)}"
+            )
         result_fields = dict()
         for result in results:
             for key, val in result.items():
@@ -142,7 +146,7 @@ class IndexTimeTestTemplate(object):
                     missing_keys.append([each_field, fields_to_check[each_field]])
             final_str = ""
             if value_list:
-                result_str = FieldTestHelper.get_table_output(
+                result_str = get_table_output(
                     headers=["Key_field", "Expected_values", "Actual_values"],
                     value_list=[
                         [
@@ -156,7 +160,7 @@ class IndexTimeTestTemplate(object):
                 final_str += f"Some values for the following key fields are missing\n\n{result_str}"
 
             if missing_keys:
-                missing_keys_result_str = FieldTestHelper.get_table_output(
+                missing_keys_result_str = get_table_output(
                     headers=["Key_field", "Expected_values"],
                     value_list=[
                         [
@@ -171,7 +175,7 @@ class IndexTimeTestTemplate(object):
 
             assert (
                 int(len(value_list)) == 0 and int(len(missing_keys)) == 0
-            ), f"For this search query: '{search}'\n{final_str}"
+            ), f"\nSearch query: {search}{final_str}\n"
 
     @pytest.mark.first
     @pytest.mark.splunk_indextime
@@ -237,7 +241,9 @@ class IndexTimeTestTemplate(object):
         results = list(results)
         LOGGER.debug("Results:{}".format(results))
         if not results:
-            assert False, "No Events found for query: " + search
+            assert False, (
+                f"\nNo Events found for query." f"{format_search_query_log(search)}"
+            )
         result_fields = {
             key: [ceil(float(item[key])) for item in results]
             for key in results[0].keys()
@@ -303,6 +309,7 @@ class IndexTimeTestTemplate(object):
         )
         count_from_results = int(results[0].get("count"))
         LOGGER.debug("Resulting count:{}".format(count_from_results))
-        assert (
-            count_from_results == expected_events_count
-        ), f"Query: {query} \nExpected count: {expected_events_count} Actual Count: {count_from_results}"
+        assert count_from_results == expected_events_count, (
+            f"{format_search_query_log(query)}"
+            f"\nExpected count: {expected_events_count} Actual Count: {count_from_results}"
+        )
