@@ -1,7 +1,21 @@
-import time
-from concurrent.futures import ProcessPoolExecutor, ThreadPoolExecutor
+#
+# Copyright 2021 Splunk Inc.
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+# http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+#
+from concurrent.futures import ThreadPoolExecutor
 
-from . import EventgenParser
+from . import PytestSplunkAddonDataParser
 from . import SampleStanza
 from itertools import cycle
 
@@ -32,14 +46,13 @@ class SampleGenerator(object):
         Generate SampleEvent object
         """
         if not SampleGenerator.sample_stanzas:
-            eventgen_parser = EventgenParser(
+            psa_data_parser = PytestSplunkAddonDataParser(
                 self.addon_path, config_path=self.config_path
             )
-            sample_stanzas = list(eventgen_parser.get_sample_stanzas())
-            SampleGenerator.conf_name = eventgen_parser.conf_name
+            sample_stanzas = psa_data_parser.get_sample_stanzas()
+            SampleGenerator.conf_name = psa_data_parser.conf_name
             with ThreadPoolExecutor(min(20, max(len(sample_stanzas), 1))) as t:
                 t.map(SampleStanza.get_raw_events, sample_stanzas)
-            # with ProcessPoolExecutor(self.process_count) as p:
             _ = list(
                 map(
                     SampleStanza.tokenize,
